searchData={"items":[{"type":"module","title":"ExRTP.Packet","doc":"RTP packet encoding and decoding functionalities.","ref":"ExRTP.Packet.html"},{"type":"module","title":"Examples - ExRTP.Packet","doc":"```elixir\n  iex> alias ExRTP.Packet\n  iex> alias ExRTP.Packet.Extension.AudioLevel\n  iex> extension = AudioLevel.new(true, 120) |> AudioLevel.to_raw(5)\n  iex> payload = <<3, 5, 5, 0>>\n  iex> encoded =\n  ...>   payload\n  ...>   |> Packet.new(\n  ...>     payload_type: 120,\n  ...>     sequence_number: 50_000,\n  ...>     timestamp: 1_000_000,\n  ...>     ssrc: 500_000\n  ...>   )\n  ...>   |> Packet.add_extension(extension)\n  ...>   |> Packet.encode()\n  iex> {:ok, %Packet{payload: ^payload}} = Packet.decode(encoded)\n  ```","ref":"ExRTP.Packet.html#module-examples"},{"type":"function","title":"ExRTP.Packet.add_extension/2","doc":"Adds RTP header extension (`RFC 8285`, multiple extensions per packet) to this packet.\n\nIf you want to use the traditional RTP extension mechanism (one extension per packet),\nsee `set_extension/3`.\n\nNote that: \n  * if this packet already has the traditional extension (`RFC 3550`, one extension per packet) set,\n  it will be removed,\n  * if the packet contained the `RFC 8285` extensions, this function will\n  append the new extension without removing previous extensions.\n\nThis function automatically decides whether to use \"one byte\" or \"two byte\" extension mechanism\n(see `RFC 8285`, sec. 4) based on the extension `data` size and its `id`:\n  * if sizes of all of the extension are in range `1..16`, and the IDs are in range `1..14`, \"one byte\" mechanism is used,\n  * if there is an extension with size in range `17..255` or equal to `0`, or with ID in range `15..255`, \"two byte\" mechanism is used,\n  * otherwise, the extension is invalid and this function will raise.","ref":"ExRTP.Packet.html#add_extension/2"},{"type":"function","title":"ExRTP.Packet.decode/1","doc":"Decodes binary into an RTP packet.\n\nIf RTP header extension is not used, `extensions` and `extension_profile` fields in the returned struct will be `nil`.\nOtherwise, `extensions` will be:\n  * a `list`, if the general mechanism for RTP header extension from `RFC 8285` is used,\n  * a `binary`, if this is a traditional header extension as defined in `RFC 3550`\n\nIf the binary is too short to be valid, this function will return error with `:not_enough_data`.","ref":"ExRTP.Packet.html#decode/1"},{"type":"function","title":"ExRTP.Packet.encode/1","doc":"Encodes an RTP packet and returns resulting binary.","ref":"ExRTP.Packet.html#encode/1"},{"type":"function","title":"ExRTP.Packet.fetch_extension/2","doc":"Fetches extension with specified `id` from this packet.\n\nIf no extension with `id` is found or `RFC 8285` extension mechanism is not used, this function will return `:error`.","ref":"ExRTP.Packet.html#fetch_extension/2"},{"type":"function","title":"ExRTP.Packet.new/2","doc":"Creates new `t:ExRTP.Packet.t/0` struct.\n\nThe `fields` parameter corresponds to the RTP packet header fields.\nRefer to `RFC 3550` for in-depth explanation.\n\nIf not passed, `payload_type`, `sequence_number`, `timestamp` and\n`ssrc` will be set to `0`, as they are often expected to be set later\nduring the processing of the packet.\n\nThe `fields` keyword list may also include:\n  * `csrc` (by default `[]`, must be shorter than `16`),\n  * `marker` (by default `false`),\n  * `padding` (by default no padding is applied)","ref":"ExRTP.Packet.html#new/2"},{"type":"function","title":"ExRTP.Packet.remove_extension/2","doc":"Removes all RTP header extension with specified ID, if there's any.\n\nThis function works only works for `RFC 8285` extensions, for the\n`RFC 3550` extension use `remove_extensions/1` instead.","ref":"ExRTP.Packet.html#remove_extension/2"},{"type":"function","title":"ExRTP.Packet.remove_extensions/1","doc":"Removes RTP header extensions form this packet.","ref":"ExRTP.Packet.html#remove_extensions/1"},{"type":"function","title":"ExRTP.Packet.set_extension/3","doc":"Sets RTP header extension (`RFC 3550`, one extension per packet) for this packet.\n\nIf you want to use the general extension mechanism from `RFC 8285` (multiple extensions per packet),\nsee `add_extension/2`.\n\nNote that:\n  * this function will overwrite any extensions set beforehand,\n  * extension must be no longer than `262_140` bytes and its length must be a multiple of `4` bytes,\n  * profile value must not be `0xBEDE` or `0x1000`.","ref":"ExRTP.Packet.html#set_extension/3"},{"type":"type","title":"ExRTP.Packet.t/0","doc":"Struct representing an RTP packet.\n\nUse `new/2` to create a new RTP packet. RTP header extensions and packet\npadding should not be modified directly, but with the use of functions in this module.","ref":"ExRTP.Packet.html#t:t/0"},{"type":"type","title":"ExRTP.Packet.uint7/0","doc":"","ref":"ExRTP.Packet.html#t:uint7/0"},{"type":"type","title":"ExRTP.Packet.uint8/0","doc":"","ref":"ExRTP.Packet.html#t:uint8/0"},{"type":"type","title":"ExRTP.Packet.uint16/0","doc":"","ref":"ExRTP.Packet.html#t:uint16/0"},{"type":"type","title":"ExRTP.Packet.uint32/0","doc":"","ref":"ExRTP.Packet.html#t:uint32/0"},{"type":"behaviour","title":"ExRTP.Packet.Extension","doc":"RTP header extension functionalities.","ref":"ExRTP.Packet.Extension.html"},{"type":"callback","title":"ExRTP.Packet.Extension.from_raw/1","doc":"Converts raw extension to extension struct.","ref":"ExRTP.Packet.Extension.html#c:from_raw/1"},{"type":"function","title":"ExRTP.Packet.Extension.new/2","doc":"Create new `t:ExRTP.Packet.Extension.t/0` struct.","ref":"ExRTP.Packet.Extension.html#new/2"},{"type":"callback","title":"ExRTP.Packet.Extension.to_raw/2","doc":"Converts extension struct to raw extension which can be used\nin `ExRTP.Packet.add_extension/2`.","ref":"ExRTP.Packet.Extension.html#c:to_raw/2"},{"type":"type","title":"ExRTP.Packet.Extension.t/0","doc":"Struct representing raw RTP header extension as defined in `RFC 8285`.","ref":"ExRTP.Packet.Extension.html#t:t/0"},{"type":"module","title":"ExRTP.Packet.Extension.AudioLevel","doc":"Audio Level Extension described in `RFC 6464`.","ref":"ExRTP.Packet.Extension.AudioLevel.html"},{"type":"function","title":"ExRTP.Packet.Extension.AudioLevel.from_raw/1","doc":"","ref":"ExRTP.Packet.Extension.AudioLevel.html#from_raw/1"},{"type":"function","title":"ExRTP.Packet.Extension.AudioLevel.new/2","doc":"Create new `t:ExRTP.Packet.Extension.AudioLevel.t/0` struct.","ref":"ExRTP.Packet.Extension.AudioLevel.html#new/2"},{"type":"function","title":"ExRTP.Packet.Extension.AudioLevel.to_raw/2","doc":"","ref":"ExRTP.Packet.Extension.AudioLevel.html#to_raw/2"},{"type":"type","title":"ExRTP.Packet.Extension.AudioLevel.level/0","doc":"","ref":"ExRTP.Packet.Extension.AudioLevel.html#t:level/0"},{"type":"type","title":"ExRTP.Packet.Extension.AudioLevel.t/0","doc":"Struct representing Audio Level Extension.","ref":"ExRTP.Packet.Extension.AudioLevel.html#t:t/0"},{"type":"module","title":"ExRTP.Packet.Extension.SourceDescription","doc":"Source Description (SDES) Extension described in `RFC 7941`.","ref":"ExRTP.Packet.Extension.SourceDescription.html"},{"type":"function","title":"ExRTP.Packet.Extension.SourceDescription.from_raw/1","doc":"","ref":"ExRTP.Packet.Extension.SourceDescription.html#from_raw/1"},{"type":"function","title":"ExRTP.Packet.Extension.SourceDescription.new/2","doc":"Create new `t:ExRTP.Packet.Extension.SourceDescription.t/0` struct.","ref":"ExRTP.Packet.Extension.SourceDescription.html#new/2"},{"type":"function","title":"ExRTP.Packet.Extension.SourceDescription.to_raw/2","doc":"","ref":"ExRTP.Packet.Extension.SourceDescription.html#to_raw/2"},{"type":"type","title":"ExRTP.Packet.Extension.SourceDescription.t/0","doc":"Struct representing SDES Extension.\n\nThe `type` field is is purely informational and ignored, when encoding/decoding the extension,\nas the SDES item types are determined by the header extension ID value, which is dynamically\nassigned in signaling and passed to the `to_raw/2` function.","ref":"ExRTP.Packet.Extension.SourceDescription.html#t:t/0"},{"type":"module","title":"ExRTP.Packet.Extension.TWCC","doc":"Transport-wide Congestion Control (TWCC) Extension\ndescribed in `draft-holmer-rmcat-transport-wide-cc-extensions-01`.","ref":"ExRTP.Packet.Extension.TWCC.html"},{"type":"function","title":"ExRTP.Packet.Extension.TWCC.from_raw/1","doc":"","ref":"ExRTP.Packet.Extension.TWCC.html#from_raw/1"},{"type":"function","title":"ExRTP.Packet.Extension.TWCC.new/1","doc":"Create new `t:ExRTP.Packet.Extension.TWCC.t/0` struct.","ref":"ExRTP.Packet.Extension.TWCC.html#new/1"},{"type":"function","title":"ExRTP.Packet.Extension.TWCC.to_raw/2","doc":"","ref":"ExRTP.Packet.Extension.TWCC.html#to_raw/2"},{"type":"type","title":"ExRTP.Packet.Extension.TWCC.t/0","doc":"Struct representing TWCC Extension.","ref":"ExRTP.Packet.Extension.TWCC.html#t:t/0"},{"type":"extras","title":"ExRTP","doc":"# ExRTP\n[![Hex.pm](https://img.shields.io/hexpm/v/ex_rtp.svg)](https://hex.pm/packages/ex_rtp)\n[![API Docs](https://img.shields.io/badge/api-docs-yellow.svg?style=flat)](https://hexdocs.pm/ex_rtp)\n[![CI](https://img.shields.io/github/actions/workflow/status/elixir-webrtc/ex_rtp/ci.yml?logo=github&label=CI)](https://github.com/elixir-webrtc/ex_rtp/actions/workflows/ci.yml)\n[![codecov](https://codecov.io/gh/elixir-webrtc/ex_rtp/graph/badge.svg?token=E98NHC8B00)](https://codecov.io/gh/elixir-webrtc/ex_rtp)\n\nImplementation of the RTP protocol in Elixir. \n\nImplements:\n- [RTP: A Transport Protocol for Real-Time Applications](https://datatracker.ietf.org/doc/html/rfc3550)\n- [A General Mechanism for RTP Header Extensions](https://datatracker.ietf.org/doc/html/rfc8285)\n\nIncludes out-of-the-box support for these RTP header extensions:\n- [A Real-time Transport Protocol (RTP) Header Extension for Client-to-Mixer Audio Level Indication](https://datatracker.ietf.org/doc/html/rfc6464)\n- [RTP Header Extension for the RTP Control Protocol (RTCP) Source Description Items](https://datatracker.ietf.org/doc/html/rfc7941)\n- [RTP Extensions for Transport-wide Congestion Control](https://datatracker.ietf.org/doc/html/draft-holmer-rmcat-transport-wide-cc-extensions-01)\n\nNew RTP header extensions can be added by implementing the `ExRTP.Packet.Extension` behaviour.\n\nSee [documentation](https://hexdocs.pm/ex_rtp/ExRTP.Packet.html) for usage examples.","ref":"readme.html"},{"type":"extras","title":"Installation - ExRTP","doc":"Add `ex_rtp` to dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:ex_rtp, \"~> 0.4.0\"}\n  ]\nend\n```","ref":"readme.html#installation"}],"content_type":"text/markdown"}